@@ -9,28 +9,34 @@ import platform
 import json
 
 # imports - module imports
-from pipupgrade             import __name__ as NAME, __version__, _pip
-from pipupgrade.util.system import pardir, makedirs, touch
-from pipupgrade.util.types  import auto_typecast
-from pipupgrade.util._dict  import autodict
-from pipupgrade._compat     import iteritems, configparser as cp
+from pipupgrade              import __name__ as NAME, __version__, _pip
+from pipupgrade.util.system  import pardir, makedirs, touch
+from pipupgrade.util.environ import getenv
+from pipupgrade.util.types   import auto_typecast
+from pipupgrade.util._dict   import autodict
+from pipupgrade._compat      import iteritems, configparser as cp
 
 PATH            = autodict()
 PATH["BASE"]    = pardir(__file__)
 PATH["DATA"]    = osp.join(PATH["BASE"], "data")
-PATH["CACHE"]   = osp.join(osp.expanduser("~"), ".%s" % NAME)
+PATH["CACHE"]   = osp.join(osp.expanduser("~"), ".config", NAME)
 
 class Configuration(object):
-
     # BUGFIX: #63 Always complains about invalid config.ini - https://github.com/achillesrasquinha/pipupgrade/issues/63
     #         Use threading.Lock() around disk IO
     locks = { "readwrite": Lock() }
 
-
     def __init__(self, location = PATH["CACHE"], name = "config"):
-        self.name     = "%s.ini" % name
-        self.location = location
-        makedirs(self.location, exist_ok = True)
+        config = getenv("CONFIG")
+
+        if not config:
+            self.name     = "%s.ini" % name
+            self.location = location
+            makedirs(self.location, exist_ok = True)
+        else:
+            self.name     = osp.basename(config)
+            self.location = osp.dirname(config)
+            
         self.config   = self.read()
 
     @classmethod
@@ -42,7 +48,6 @@ class Configuration(object):
             self.locks[key].release()
             del self.locks[key]
 
-
     def read(self):
         with self.locks['readwrite']:
             path        = osp.join(self.location, self.name)
@@ -82,8 +87,6 @@ class Configuration(object):
             config.set(section, key, value)
             self.write()
 
-
-
 class Settings(object):
     _DEFAULTS = {
               "version": __version__,
@@ -123,11 +126,13 @@ def environment():
     environ["config"]           = dict(
         path = dict(PATH)
     )
-    environ["pip_executables"]  = [dict(
-        executable = executable,
-        version    = _pip.call("--version", pip_exec = executable,
-            output = True)[1]
-    ) for executable in _pip._PIP_EXECUTABLES]
+
+    # NOTE: Doesn't comply with "--pip-path" flag.
+    # environ["pip_executables"]  = [dict(
+    #     executable = executable,
+    #     version    = _pip.call("--version", pip_exec = executable,
+    #         output = True)[1]
+    # ) for executable in _pip._PIP_EXECUTABLES]
 
     from pipupgrade import settings
     environ["settings"]         = settings.to_dict()
