@@ -9,6 +9,6 @@ def test_environment():
     details = environment()
 
     assert all((k in details for k in ("version", "python_version", "os",
-        "config", "pip_executables")))
+        "config"))) #, "pip_executables")))
 
     return details
\ No newline at end of file
